#
# spec file for package ghc-hledger-iadd
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pkg_name hledger-iadd
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        1.3.1
Release:        3.19
Summary:        A terminal UI as drop-in replacement for hledger add
License:        BSD-3-Clause
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
Source1:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/revision/2.cabal#/%{pkg_name}.cabal
BuildRequires:  chrpath
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-brick-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-free-devel
BuildRequires:  ghc-hledger-lib-devel
BuildRequires:  ghc-megaparsec-devel
BuildRequires:  ghc-microlens-devel
BuildRequires:  ghc-microlens-th-devel
BuildRequires:  ghc-optparse-applicative-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-semigroups-devel
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-text-format-devel
BuildRequires:  ghc-text-zipper-devel
BuildRequires:  ghc-time-devel
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-unordered-containers-devel
BuildRequires:  ghc-vector-devel
BuildRequires:  ghc-vty-devel
BuildRequires:  ghc-xdg-basedir-devel
%if %{with tests}
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-hspec-devel
%endif

%description
This is a terminal UI as drop-in replacement for hledger add.

It improves in the following ways on hledger's add command:

* Interactive as-you-type completion for account names and descriptions with
optional fuzzy matching.

* Integrated calculator: Amounts can be written as simple sums with real-time
feedback on the result.

* All actions while entering a transaction can be undone

* Configurable format for date input. Instead of 'y/m/d' it is also possible to
use other formats like the german 'd.m.y'.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Haskell
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}
cp -p %{SOURCE1} %{pkg_name}.cabal

%build
%ghc_lib_build

%install
%ghc_lib_install
%ghc_fix_rpath %{pkg_name}-%{version}

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%doc LICENSE
%{_bindir}/%{pkg_name}

%files devel -f %{name}-devel.files
%doc ChangeLog.md README.md doc

%changelog
* Tue Jan  2 2018 psimons@suse.com
- Update to version 1.3.1.
  A more detailed change log is not available.
* Fri Dec 22 2017 psimons@suse.com
- Update to version 1.3.0.
  A more detailed change log is not available.
* Sat Dec 16 2017 psimons@suse.com
- Update to version 1.2.6 revision 8.
  A more detailed change log is not available.
* Fri Dec 15 2017 psimons@suse.com
- Update to version 1.2.6 revision 7.
  A more detailed change log is not available.
* Wed Nov  8 2017 psimons@suse.com
- Update to version 1.2.6 revision 6.
  A more detailed change log is not available.
* Wed Oct 11 2017 psimons@suse.com
- Update to version 1.2.6 revision 5.
  A more detailed change log is not available.
* Sun Oct  8 2017 psimons@suse.com
- Update to version 1.2.6 revision 4.
  A more detailed change log is not available.
* Wed Oct  4 2017 psimons@suse.com
- Update to version 1.2.6 revision 3.
  A more detailed change log is not available.
* Sun Oct  1 2017 psimons@suse.com
- Update to version 1.2.6 revision 2.
  A more detailed change log is not available.
* Mon Sep 25 2017 psimons@suse.com
- Update to version 1.2.6 revision 1.
  A more detailed change log is not available.
* Tue Sep 19 2017 psimons@suse.com
- Update to version 1.2.6.
  A more detailed change log is not available.
* Mon Sep 11 2017 psimons@suse.com
- Update to version 1.2.4.
  A more detailed change log is not available.
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Sun Jun 25 2017 psimons@suse.com
- Update to version 1.2.1 revision 2.
* Mon May  8 2017 psimons@suse.com
- Update to version 1.2.1 revision 1 with cabal2obs.
* Tue Apr  4 2017 psimons@suse.com
- Update to version 1.2.1 with cabal2obs.
* Sun Feb 12 2017 psimons@suse.com
- Update to version 1.2 with cabal2obs.
